==> ejc-assistrmat-api-3.0.0-20220913.095753-195-sources.jar: com/ejianc/business/outrmat/consts/OutRmatConstant.java <==
package com.ejianc.business.outrmat.consts;

/**
 * 单据名称常量
 */
public class OutRmatConstant {

    public static final String 验收单 = "验收单";
    public static final String 启用单 = "启用单";
    public static final String 停用单 = "停用单";
    public static final String 退赔单 = "退赔单";
    public static final String 遗失单 = "遗失单";
    public static final String 租金计算单 = "租金计算单";
    public static final String 补充协议 = "补充协议";
    public static final String 变更单 = "变更单";
    public static final String 冻结单 = "冻结单";
    public static final String 解除单 = "解除单";
    public static final String 发货单 = "发货单";
    
    public static final String 保存 = "保存";
    public static final String 弃审 = "弃审";

    public static final String CONTRACT_REFCODE = "am_contract"; // 辅料中心采购合同refcode
    public static final String CONTRACT_REFCODE_CHANGE = "am_contract_change"; // 辅料中心采购合同变更refcode
    public static final String CONTRACT_RECORD_REFCODE = "am_contract_record"; // 辅料中心采购合同记录refcode
    public static final String CONTRACT_RECORD_RELIEVE = "am_contract_relieve"; // 辅料中心采购合同解除refcode

    public static final String CONTRACT_FILE_SOURCE_TYPE = "amContractFile"; // 辅料中心采购合同附件业务类型
    public static final String CONTRACT_ATTACH_SOURCE_TYPE = "amContract"; // 辅料中心采购合同附件管理业务类型

    public static final String CONTRACT_CHANGE_FILE_SOURCE_TYPE = "amContractChangeFile"; // 辅料中心采购合同变更附件业务类型
    public static final String CONTRACT_CHANGE_ATTACH_SOURCE_TYPE = "amContractChange"; // 辅料中心采购合同变更附件管理业务类型

    public static final String CONTRACT_RECORD_FILE_SOURCE_TYPE = "amContractRecordFile"; // 辅料中心采购合同记录附件业务类型
    public static final String CONTRACT_RECORD_ATTACH_SOURCE_TYPE = "amContractRecord"; // 辅料中心采购合同记录附件管理业务类型

    /**
     * 通用变更类型：0-新增项
     */
    public static final Integer CHANGE_TYPE_ADD = 0;
    
    /**
     * 通用变更类型：1-删除项
     */
    public static final Integer CHANGE_TYPE_DEL = 1;
    
    /**
     * 通用变更类型：2-内容便更
     */
    public static final Integer CHANGE_TYPE_CONTENT_CHANGE = 2;

    /**
     * 辅料中心租出合同-外租
     */
    public static final String OUT_RMAT_CONTRACT_RENT_TYPE_OUT = "0";
    /**
     * 辅料中心租出合同-内租
     */
    public static final String OUT_RMAT_CONTRACT_RENT_TYPE_IN = "1";
    
}

==> ejc-assistrmat-api-3.0.0-20220915.064758-213-sources.jar: com/ejianc/business/outrmat/consts/OutRmatConstant.java <==
package com.ejianc.business.outrmat.consts;

/**
 * 单据名称常量
 */
public class OutRmatConstant {

    public static final String 验收单 = "验收单";
    public static final String 启用单 = "启用单";
    public static final String 停用单 = "停用单";
    public static final String 退赔单 = "退赔单";
    public static final String 遗失单 = "遗失单";
    public static final String 租金计算单 = "租金计算单";
    public static final String 补充协议 = "补充协议";
    public static final String 变更单 = "变更单";
    public static final String 冻结单 = "冻结单";
    public static final String 解除单 = "解除单";
    public static final String 发货单 = "发货单";
    
    public static final String 保存 = "保存";
    public static final String 弃审 = "弃审";

    public static final String CONTRACT_REFCODE = "am_contract"; // 辅料中心采购合同refcode
    public static final String CONTRACT_REFCODE_CHANGE = "am_contract_change"; // 辅料中心采购合同变更refcode
    public static final String CONTRACT_RECORD_REFCODE = "am_contract_record"; // 辅料中心采购合同记录refcode
    public static final String CONTRACT_RECORD_RELIEVE = "am_contract_relieve"; // 辅料中心采购合同解除refcode

    public static final String CONTRACT_FILE_SOURCE_TYPE = "amContractFile"; // 辅料中心采购合同附件业务类型
    public static final String CONTRACT_ATTACH_SOURCE_TYPE = "amContract"; // 辅料中心采购合同附件管理业务类型

    public static final String CONTRACT_CHANGE_FILE_SOURCE_TYPE = "amContractChangeFile"; // 辅料中心采购合同变更附件业务类型
    public static final String CONTRACT_CHANGE_ATTACH_SOURCE_TYPE = "amContractChange"; // 辅料中心采购合同变更附件管理业务类型

    public static final String CONTRACT_RECORD_FILE_SOURCE_TYPE = "amContractRecordFile"; // 辅料中心采购合同记录附件业务类型
    public static final String CONTRACT_RECORD_ATTACH_SOURCE_TYPE = "amContractRecord"; // 辅料中心采购合同记录附件管理业务类型

    /**
     * 通用变更类型：0-新增项
     */
    public static final Integer CHANGE_TYPE_ADD = 0;
    
    /**
     * 通用变更类型：1-删除项
     */
    public static final Integer CHANGE_TYPE_DEL = 1;
    
    /**
     * 通用变更类型：2-内容便更
     */
    public static final Integer CHANGE_TYPE_CONTENT_CHANGE = 2;

    /**
     * 辅料中心租出合同-外租
     */
    public static final String OUT_RMAT_CONTRACT_RENT_TYPE_OUT = "0";
    /**
     * 辅料中心租出合同-内租
     */
    public static final String OUT_RMAT_CONTRACT_RENT_TYPE_IN = "1";

    /**
     * 推送周转材：新增
     */
    public static final Integer PUSH_RMAT_OPT_TYPE_ADD = 1;
    /**
     * 推送周转材：删除
     */
    public static final Integer PUSH_RMAT_OPT_TYPE_DEL = 2;

    /**推送周转材单据：合同  */
    public static final String PUSH_RMAT_OPT_BILL_CONTRACT = "contract";
    /**推送周转材单据：合同变更  */
    public static final String PUSH_RMAT_OPT_BILL_CONTRACT_CHANGE = "contractChange";
    /**推送周转材单据：合同解除  */
    public static final String PUSH_RMAT_OPT_BILL_CONTRACT_RELIEVE = "contractRelieve";
    /**推送周转材单据：合同冻结  */
    public static final String PUSH_RMAT_OPT_BILL_CONTRACT_FREEZE = "contractFreeze";
    /**推送周转材单据：合同变更修改  */
    public static final String PUSH_RMAT_OPT_BILL_CONTRACT_CHANGE_U = "contractChangeUpdate";
    
}
